@@ -1,7 +1,7 @@
 use utf8;
 use warnings;
 no warnings 'redefine';
-use vars qw($remote_addr, $query_string,$referer,@count);
+use vars qw($remote_addr $query_string $referer @count);
 $remote_addr  = CGI::remote_addr()  ? CGI::remote_addr()  : 'none';
 $query_string = CGI::query_string() ? CGI::query_string() : 'none';
 $referer      = CGI::referer()      ? CGI::referer()      : 'none';
