@@ -2,8 +2,9 @@
 use strict;
 use utf8;
 use warnings;
+use diagnostics;
 use CGI::Carp qw(fatalsToBrowser);
-use lib qw(lib);
+use lib qw(%PATH%lib);
 use MySQL::Admin::GUI;
-ContentHeader("%PATH%/config/settings.pl");
-&Body();
\ No newline at end of file
+ContentHeader("%PATH%config/settings.pl");
+Body();
\ No newline at end of file
