@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-use lib qw(../lib);
+use lib qw(/var/www/cgi-bin/examples/lib);
 use HTML::Menu::Pages;
 use Cwd;
 my $cwd  = cwd();
@@ -12,7 +12,7 @@ my %needed = (
 
     length => '345',
 
-    style => 'lze',
+    style => 'mysql',
 
     action => "Pages",
 
